@@ -19,13 +19,11 @@
     02110-1301, USA.
 */
 
-#ifndef BREADCRUBS_WIDGET_H
-#define BREADCRUBS_WIDGET_H
+#ifndef BREADCRUMBS_WIDGET_H
+#define BREADCRUMBS_WIDGET_H
 
 #include <QWidget>
 #include <QItemSelection>
-#include <QLabel>
-#include <QListView>
 #include <kselectionproxymodel.h>
 
 #include "klinkitemselectionmodel.h"
